# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.ucb.IOErrorCode import IOErrorCodeProto

class IOErrorCode(Enum):
    """
    Enum Class


    See Also:
        `API IOErrorCode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.IOErrorCode'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.ucb.IOErrorCode'

    ABORT = cast("IOErrorCodeProto", 'ABORT')
    """
    An operation was aborted.
    """
    ACCESS_DENIED = cast("IOErrorCodeProto", 'ACCESS_DENIED')
    """
    An object cannot be accessed due to insufficient user rights.
    """
    ALREADY_EXISTING = cast("IOErrorCodeProto", 'ALREADY_EXISTING')
    """
    An object already exists.
    """
    BAD_CRC = cast("IOErrorCodeProto", 'BAD_CRC')
    """
    A bad checksum.
    """
    CANT_CREATE = cast("IOErrorCodeProto", 'CANT_CREATE')
    """
    An object could not be created.
    """
    CANT_READ = cast("IOErrorCodeProto", 'CANT_READ')
    """
    Data could not be read from a file.
    """
    CANT_SEEK = cast("IOErrorCodeProto", 'CANT_SEEK')
    """
    A seek operation could not be run.
    """
    CANT_TELL = cast("IOErrorCodeProto", 'CANT_TELL')
    """
    A tell operation could not be run.
    """
    CANT_WRITE = cast("IOErrorCodeProto", 'CANT_WRITE')
    """
    Data could not be written to a file.
    """
    CURRENT_DIRECTORY = cast("IOErrorCodeProto", 'CURRENT_DIRECTORY')
    """
    A function is not possible because the path contains the current directory.
    """
    DEVICE_NOT_READY = cast("IOErrorCodeProto", 'DEVICE_NOT_READY')
    """
    A device (drive) not ready.
    """
    DIFFERENT_DEVICES = cast("IOErrorCodeProto", 'DIFFERENT_DEVICES')
    """
    A function is not possible because the devices (drives) are not identical.
    """
    GENERAL = cast("IOErrorCodeProto", 'GENERAL')
    """
    A general input/output error.
    """
    INVALID_ACCESS = cast("IOErrorCodeProto", 'INVALID_ACCESS')
    """
    An invalid attempt was made to access an object.
    """
    INVALID_CHARACTER = cast("IOErrorCodeProto", 'INVALID_CHARACTER')
    """
    A file name contains invalid characters.
    """
    INVALID_DEVICE = cast("IOErrorCodeProto", 'INVALID_DEVICE')
    """
    A specified device is invalid.
    """
    INVALID_LENGTH = cast("IOErrorCodeProto", 'INVALID_LENGTH')
    """
    Invalid data length.
    """
    INVALID_PARAMETER = cast("IOErrorCodeProto", 'INVALID_PARAMETER')
    """
    An operation was started with an invalid parameter.
    """
    IS_WILDCARD = cast("IOErrorCodeProto", 'IS_WILDCARD')
    """
    An operation cannot be run on file names containing wildcards.
    """
    LOCKING_VIOLATION = cast("IOErrorCodeProto", 'LOCKING_VIOLATION')
    """
    A locking problem.
    """
    MISPLACED_CHARACTER = cast("IOErrorCodeProto", 'MISPLACED_CHARACTER')
    """
    An invalid file name.
    """
    NAME_TOO_LONG = cast("IOErrorCodeProto", 'NAME_TOO_LONG')
    """
    A file name is too long.
    """
    NOT_EXISTING = cast("IOErrorCodeProto", 'NOT_EXISTING')
    """
    A nonexistent object.
    """
    NOT_EXISTING_PATH = cast("IOErrorCodeProto", 'NOT_EXISTING_PATH')
    """
    The path to a file does not exist.
    """
    NOT_SUPPORTED = cast("IOErrorCodeProto", 'NOT_SUPPORTED')
    """
    An action is not supported.
    """
    NO_DIRECTORY = cast("IOErrorCodeProto", 'NO_DIRECTORY')
    """
    An object is not a directory.
    """
    NO_FILE = cast("IOErrorCodeProto", 'NO_FILE')
    """
    An object is not a file.
    """
    OUT_OF_DISK_SPACE = cast("IOErrorCodeProto", 'OUT_OF_DISK_SPACE')
    """
    No more space on a device.
    """
    OUT_OF_FILE_HANDLES = cast("IOErrorCodeProto", 'OUT_OF_FILE_HANDLES')
    """
    No more file handles available.
    """
    OUT_OF_MEMORY = cast("IOErrorCodeProto", 'OUT_OF_MEMORY')
    """
    An operation could not be run due to insufficient memory.
    """
    PENDING = cast("IOErrorCodeProto", 'PENDING')
    """
    An operation is still pending.
    """
    RECURSIVE = cast("IOErrorCodeProto", 'RECURSIVE')
    """
    An object cannot be copied into itself.
    """
    UNKNOWN = cast("IOErrorCodeProto", 'UNKNOWN')
    """
    Unknown.
    
    An unknown I/O error has occurred.
    """
    WRITE_PROTECTED = cast("IOErrorCodeProto", 'WRITE_PROTECTED')
    """
    A function is not possible because the object is write protected.
    """
    WRONG_FORMAT = cast("IOErrorCodeProto", 'WRONG_FORMAT')
    """
    An incorrect file format.
    """
    WRONG_VERSION = cast("IOErrorCodeProto", 'WRONG_VERSION')
    """
    An incorrect file version.
    """

__all__ = ['IOErrorCode']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.table.accessible_cell_view import AccessibleCellView as AccessibleCellView
from ...lo.table.accessible_table_view import AccessibleTableView as AccessibleTableView
from ...lo.table.border_line import BorderLine as BorderLine
from ...lo.table.border_line2 import BorderLine2 as BorderLine2
from ...lo.table.border_line_style import BorderLineStyle as BorderLineStyle
from ...lo.table.cell import Cell as Cell
from ...lo.table.cell_address import CellAddress as CellAddress
from ...lo.table.cell_content_type import CellContentType as CellContentType
from ...lo.table.cell_cursor import CellCursor as CellCursor
from ...lo.table.cell_hori_justify import CellHoriJustify as CellHoriJustify
from ...lo.table.cell_justify_method import CellJustifyMethod as CellJustifyMethod
from ...lo.table.cell_orientation import CellOrientation as CellOrientation
from ...lo.table.cell_properties import CellProperties as CellProperties
from ...lo.table.cell_range import CellRange as CellRange
from ...lo.table.cell_range_address import CellRangeAddress as CellRangeAddress
from ...lo.table.cell_range_list_source import CellRangeListSource as CellRangeListSource
from ...lo.table.cell_value_binding import CellValueBinding as CellValueBinding
from ...lo.table.cell_vert_justify import CellVertJustify as CellVertJustify
from ...lo.table.cell_vert_justify2 import CellVertJustify2 as CellVertJustify2
from ...lo.table.list_position_cell_binding import ListPositionCellBinding as ListPositionCellBinding
from ...lo.table.shadow_format import ShadowFormat as ShadowFormat
from ...lo.table.shadow_location import ShadowLocation as ShadowLocation
from ...lo.table.table_border import TableBorder as TableBorder
from ...lo.table.table_border2 import TableBorder2 as TableBorder2
from ...lo.table.table_border_distances import TableBorderDistances as TableBorderDistances
from ...lo.table.table_chart import TableChart as TableChart
from ...lo.table.table_charts import TableCharts as TableCharts
from ...lo.table.table_charts_enumeration import TableChartsEnumeration as TableChartsEnumeration
from ...lo.table.table_column import TableColumn as TableColumn
from ...lo.table.table_columns import TableColumns as TableColumns
from ...lo.table.table_columns_enumeration import TableColumnsEnumeration as TableColumnsEnumeration
from ...lo.table.table_orientation import TableOrientation as TableOrientation
from ...lo.table.table_row import TableRow as TableRow
from ...lo.table.table_rows import TableRows as TableRows
from ...lo.table.table_rows_enumeration import TableRowsEnumeration as TableRowsEnumeration
from ...lo.table.table_sort_descriptor import TableSortDescriptor as TableSortDescriptor
from ...lo.table.table_sort_descriptor2 import TableSortDescriptor2 as TableSortDescriptor2
from ...lo.table.table_sort_field import TableSortField as TableSortField
from ...lo.table.table_sort_field_type import TableSortFieldType as TableSortFieldType
from ...lo.table.x_auto_formattable import XAutoFormattable as XAutoFormattable
from ...lo.table.x_cell import XCell as XCell
from ...lo.table.x_cell2 import XCell2 as XCell2
from ...lo.table.x_cell_cursor import XCellCursor as XCellCursor
from ...lo.table.x_cell_range import XCellRange as XCellRange
from ...lo.table.x_column_row_range import XColumnRowRange as XColumnRowRange
from ...lo.table.x_mergeable_cell import XMergeableCell as XMergeableCell
from ...lo.table.x_mergeable_cell_range import XMergeableCellRange as XMergeableCellRange
from ...lo.table.x_table import XTable as XTable
from ...lo.table.x_table_chart import XTableChart as XTableChart
from ...lo.table.x_table_charts import XTableCharts as XTableCharts
from ...lo.table.x_table_charts_supplier import XTableChartsSupplier as XTableChartsSupplier
from ...lo.table.x_table_columns import XTableColumns as XTableColumns
from ...lo.table.x_table_pivot_chart import XTablePivotChart as XTablePivotChart
from ...lo.table.x_table_pivot_charts import XTablePivotCharts as XTablePivotCharts
from ...lo.table.x_table_pivot_charts_supplier import XTablePivotChartsSupplier as XTablePivotChartsSupplier
from ...lo.table.x_table_rows import XTableRows as XTableRows



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from .transfer_info import TransferInfo as TransferInfo_a4600b13
import typing


class TransferInfo2(TransferInfo_a4600b13):
    """
    Struct Class

    extends TransferInfo structure to give some additional parameters for transfers.

    See Also:
        `API TransferInfo2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1TransferInfo2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.TransferInfo2'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.TransferInfo2'
    """Literal Constant ``com.sun.star.ucb.TransferInfo2``"""

    def __init__(self, MoveData: typing.Optional[bool] = False, SourceURL: typing.Optional[str] = '', NewTitle: typing.Optional[str] = '', NameClash: typing.Optional[int] = 0, MimeType: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            MoveData (bool, optional): MoveData value.
            SourceURL (str, optional): SourceURL value.
            NewTitle (str, optional): NewTitle value.
            NameClash (int, optional): NameClash value.
            MimeType (str, optional): MimeType value.
        """

        if isinstance(MoveData, TransferInfo2):
            oth: TransferInfo2 = MoveData
            self.MoveData = oth.MoveData
            self.SourceURL = oth.SourceURL
            self.NewTitle = oth.NewTitle
            self.NameClash = oth.NameClash
            self.MimeType = oth.MimeType
            return

        kargs = {
            "MoveData": MoveData,
            "SourceURL": SourceURL,
            "NewTitle": NewTitle,
            "NameClash": NameClash,
            "MimeType": MimeType,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._mime_type = kwargs["MimeType"]
        inst_keys = ('MimeType',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def MimeType(self) -> str:
        """
        contains the MIME type of the source of the action
        """
        return self._mime_type

    @MimeType.setter
    def MimeType(self, value: str) -> None:
        self._mime_type = value


__all__ = ['TransferInfo2']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XDefaultProperty(XInterface_8f010a43):
    """
    An object supporting this interface indicates to interested parties or clients the name of the default property for this object.
    
    For example where ExampleObject is an instance of an Object that supports this interface which returns the default property name \"Value\".A scripting engine could use this information to support syntax like
    
    ExampleObject = \"foo\"
    
    which would be equivalent to writing
    
    ExampleObject.Value = \"foo\"
    
    or
    
    bar = ExampleObject
    
    which would be equivalent to writing
    
    bar = ExampleObject.Value

    See Also:
        `API XDefaultProperty <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XDefaultProperty.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.XDefaultProperty'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.XDefaultProperty'

    @abstractmethod
    def getDefaultPropertyName(self) -> str:
        """
        Returns the name of the default property.
        """
        ...

__all__ = ['XDefaultProperty']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..beans.named_value import NamedValue as NamedValue_a37a0af3
from ..util.url import URL as URL_57ad07b9


class ControlEvent(object):
    """
    Struct Class

    describes a control event sent by extended user interface controls.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API ControlEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1frame_1_1ControlEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.ControlEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.frame.ControlEvent'
    """Literal Constant ``com.sun.star.frame.ControlEvent``"""

    def __init__(self, aInformation: typing.Optional[typing.Tuple[NamedValue_a37a0af3, ...]] = (), aURL: typing.Optional[URL_57ad07b9] = UNO_NONE, Event: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            aInformation (typing.Tuple[NamedValue, ...], optional): aInformation value.
            aURL (URL, optional): aURL value.
            Event (str, optional): Event value.
        """
        super().__init__()

        if isinstance(aInformation, ControlEvent):
            oth: ControlEvent = aInformation
            self.aInformation = oth.aInformation
            self.aURL = oth.aURL
            self.Event = oth.Event
            return

        kargs = {
            "aInformation": aInformation,
            "aURL": aURL,
            "Event": Event,
        }
        if kargs["aURL"] is UNO_NONE:
            kargs["aURL"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._a_information = kwargs["aInformation"]
        self._a_url = kwargs["aURL"]
        self._event = kwargs["Event"]


    @property
    def aInformation(self) -> typing.Tuple[NamedValue_a37a0af3, ...]:
        """
        specifies a sequence of named values which are used as additional values for the event.
        
        The number and types of named values depend on the event.
        """
        return self._a_information

    @aInformation.setter
    def aInformation(self, value: typing.Tuple[NamedValue_a37a0af3, ...]) -> None:
        self._a_information = value

    @property
    def aURL(self) -> URL_57ad07b9:
        """
        fully parsed URL describing the control that sends this notification.
        """
        return self._a_url

    @aURL.setter
    def aURL(self, value: URL_57ad07b9) -> None:
        self._a_url = value

    @property
    def Event(self) -> str:
        """
        specifies the event which has occurred.
        """
        return self._event

    @Event.setter
    def Event(self, value: str) -> None:
        self._event = value


__all__ = ['ControlEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractproperty
from .uno_control_model import UnoControlModel as UnoControlModel_c8ce0c58
if typing.TYPE_CHECKING:
    from ..util.color import Color as Color_68e908c5

class UnoControlScrollBarModel(UnoControlModel_c8ce0c58):
    """
    Service Class

    specifies the standard model of a UnoControlScrollBar.
    
    **since**
    
        OOo 2.0

    See Also:
        `API UnoControlScrollBarModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlScrollBarModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.UnoControlScrollBarModel'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BackgroundColor(self) -> Color_68e908c5:
        """
        specifies the RGB color to be used for the control.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def BlockIncrement(self) -> int:
        """
        specifies the increment for a block move.
        """
        ...

    @abstractproperty
    def Border(self) -> int:
        """
        specifies the border style of the control.
        """
        ...

    @abstractproperty
    def BorderColor(self) -> int:
        """
        specifies the color of the border, if present
        
        Not every border style (see Border) may support coloring. For instance, usually a border with 3D effect will ignore the BorderColor setting.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def Enabled(self) -> bool:
        """
        determines whether the control is enabled or disabled.
        """
        ...

    @abstractproperty
    def HelpText(self) -> str:
        """
        specifies the help text of the control.
        """
        ...

    @abstractproperty
    def HelpURL(self) -> str:
        """
        specifies the help URL of the control.
        """
        ...

    @abstractproperty
    def LineIncrement(self) -> int:
        """
        specifies the increment for a single line move.
        """
        ...

    @abstractproperty
    def LiveScroll(self) -> bool:
        """
        specifies the scrolling behavior of the control.
        
        TRUE means, that when the user moves the slider in the scroll bar, the content of the window is updated immediately. FALSE means, that the window is only updated after the user has released the mouse button.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def Orientation(self) -> int:
        """
        specifies the ScrollBarOrientation of the control.
        """
        ...

    @abstractproperty
    def Printable(self) -> bool:
        """
        specifies that the control will be printed with the document.
        """
        ...

    @abstractproperty
    def RepeatDelay(self) -> int:
        """
        specifies the mouse repeat delay, in milliseconds.
        
        When the user presses a mouse in a control area where this triggers an action (such as scrolling the scrollbar), then usual control implementations allow to repeatedly trigger this action, without the need to release the mouse button and to press it again. The delay between two such triggers is specified with this property.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def ScrollValue(self) -> int:
        """
        specifies the scroll value of the control.
        """
        ...

    @abstractproperty
    def ScrollValueMax(self) -> int:
        """
        specifies the maximum scroll value of the control.
        """
        ...

    @abstractproperty
    def ScrollValueMin(self) -> int:
        """
        specifies the minimum scroll value of the control.
        
        If this optional property is not present, clients of the component should assume a minimal scroll value of 0.
        """
        ...

    @abstractproperty
    def SymbolColor(self) -> Color_68e908c5:
        """
        specifies the RGB color to be used when painting symbols which are part of the control's appearance, such as the arrow buttons.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def Tabstop(self) -> bool:
        """
        specifies that the control can be reached with the TAB key.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def VisibleSize(self) -> int:
        """
        specifies the visible size of the scroll bar.
        """
        ...


__all__ = ['UnoControlScrollBarModel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report
from __future__ import annotations
import typing
from abc import abstractproperty
from .x_report_control_model import XReportControlModel as XReportControlModel_2d800f4a
if typing.TYPE_CHECKING:
    from ..util.x_number_formats_supplier import XNumberFormatsSupplier as XNumberFormatsSupplier_3afb0fb7

class XFormattedField(XReportControlModel_2d800f4a):
    """
    describes a control which can be used for displaying values with an arbitrary formatting.

    See Also:
        `API XFormattedField <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XFormattedField.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.report'
    __ooo_full_ns__: str = 'com.sun.star.report.XFormattedField'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.report.XFormattedField'

    @abstractproperty
    def FormatKey(self) -> int:
        """
        specifies the format to be used when formatting the field input and output.
        
        This value is meaningful relative to the FormatsSupplier attribute only.
        """
        ...

    @abstractproperty
    def FormatsSupplier(self) -> XNumberFormatsSupplier_3afb0fb7:
        """
        supplies the formats the field should work with.
        """
        ...


__all__ = ['XFormattedField']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from ..style.page_style import PageStyle as PageStyle_9b210ac7
if typing.TYPE_CHECKING:
    from .x_header_footer_content import XHeaderFooterContent as XHeaderFooterContent_275c0f0c

class TablePageStyle(PageStyle_9b210ac7):
    """
    Service Class

    represents a page style for a spreadsheet.
    
    This service extends the service com.sun.star.style.PageStyle with spreadsheet specific properties.
    
    **since**
    
        OOo 2.0

    See Also:
        `API TablePageStyle <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1TablePageStyle.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.TablePageStyle'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CenterHorizontally(self) -> bool:
        """
        determines whether the table is centered horizontally on the page.
        """
        ...

    @abstractproperty
    def CenterVertically(self) -> bool:
        """
        determines whether the table is centered vertically on the page.
        """
        ...

    @abstractproperty
    def FirstPageNumber(self) -> int:
        """
        contains the page number applied to the first page for this sheet.
        
        The value 0 indicates that the page numbers are continued from the previous sheet.
        """
        ...

    @abstractproperty
    def LeftPageFooterContent(self) -> XHeaderFooterContent_275c0f0c:
        """
        contains the content of the footer for left pages.
        
        After changing the footer text contents, this property has to be reinserted into the property set.
        """
        ...

    @abstractproperty
    def LeftPageHeaderContent(self) -> XHeaderFooterContent_275c0f0c:
        """
        contains the content of the header for left pages.
        
        After changing the header text contents, this property has to be reinserted into the property set.
        """
        ...

    @abstractproperty
    def PageScale(self) -> int:
        """
        contains the scaling factor (in percent) for printing the sheet.
        """
        ...

    @abstractproperty
    def PrintAnnotations(self) -> bool:
        """
        enables printing of cell annotations.
        """
        ...

    @abstractproperty
    def PrintCharts(self) -> bool:
        """
        enables printing of charts.
        """
        ...

    @abstractproperty
    def PrintDownFirst(self) -> bool:
        """
        specifies the print order for the pages within each sheet.
        
        If TRUE, the order for printing pages begins with top-to-bottom, then continues with the next set of cell columns to the right. If FALSE, the order for printing pages begins with left-to-right, then continues with the next set of cell rows to the bottom.
        """
        ...

    @abstractproperty
    def PrintDrawing(self) -> bool:
        """
        enables printing of drawing objects.
        """
        ...

    @abstractproperty
    def PrintFormulas(self) -> bool:
        """
        enables printing of formulas instead of their results.
        """
        ...

    @abstractproperty
    def PrintGrid(self) -> bool:
        """
        enables printing of the cell grid.
        """
        ...

    @abstractproperty
    def PrintHeaders(self) -> bool:
        """
        enables printing of column and row headers.
        """
        ...

    @abstractproperty
    def PrintObjects(self) -> bool:
        """
        enables printing of embedded objects.
        """
        ...

    @abstractproperty
    def PrintZeroValues(self) -> bool:
        """
        enables printing of zero-values.
        """
        ...

    @abstractproperty
    def RightPageFooterContent(self) -> XHeaderFooterContent_275c0f0c:
        """
        contains the content of the footer for right pages.
        
        After changing the footer text contents, this property has to be reinserted into the property set.
        """
        ...

    @abstractproperty
    def RightPageHeaderContent(self) -> XHeaderFooterContent_275c0f0c:
        """
        contains the content of the header for right pages.
        
        After changing the header text contents, this property has to be reinserted into the property set.
        """
        ...

    @abstractproperty
    def ScaleToPages(self) -> int:
        """
        contains the number of pages the sheet will printed.
        """
        ...

    @abstractproperty
    def ScaleToPagesX(self) -> int:
        """
        contains the number of horizontal pages the sheet will printed on.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def ScaleToPagesY(self) -> int:
        """
        contains the number of vertical pages the sheet will printed on.
        
        **since**
        
            OOo 2.0
        """
        ...


__all__ = ['TablePageStyle']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6

class LinkTargets(XNameAccess_e2ab0cf6):
    """
    Service Class

    This service gives access to a collection of names that are child links of the parent object that supplied this service.
    
    The com.sun.star.container.XNameAccess returns elements of com.sun.star.beans.XPropertySet that implement the service LinkTarget.

    See Also:
        `API LinkTargets <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1document_1_1LinkTargets.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.LinkTargets'
    __ooo_type_name__: str = 'service'


__all__ = ['LinkTargets']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.security


class CertificateValidity(object):
    """
    Const Class

    Constant definition of a certificate characters.
    
    The certificate characters will be defined as bit-wise constants.

    See Also:
        `API CertificateValidity <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1security_1_1CertificateValidity.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.security'
    __ooo_full_ns__: str = 'com.sun.star.security.CertificateValidity'
    __ooo_type_name__: str = 'const'

    VALID = 0
    INVALID = 1
    """
    The certificate is invalid.
    """
    UNTRUSTED = 2
    """
    The certificate itself is untrusted.
    """
    TIME_INVALID = 4
    """
    The current time is not in the range of time for which the certificate is valid.
    """
    NOT_TIME_NESTED = 8
    """
    The time range of a certificate does not fall within the time range of the issuing certificate.
    """
    REVOKED = 16
    """
    It is a revoked certificate.
    """
    UNKNOWN_REVOKATION = 32
    """
    The certificate revocation status is unknown.
    """
    SIGNATURE_INVALID = 64
    """
    The certificate signature is invalid.
    """
    EXTENSION_INVALID = 128
    """
    The certificate has invalid extensions.
    """
    EXTENSION_UNKNOWN = 256
    """
    The certificate has critical unknown extensions.
    """
    ISSUER_UNKNOWN = 512
    """
    The certificate issuer is unknown.
    """
    ISSUER_UNTRUSTED = 1024
    """
    The certificate issuer is untrusted.
    """
    ISSUER_INVALID = 4096
    """
    The certificate issuer is invalid.
    """
    ROOT_UNKNOWN = 8192
    """
    The root certificate is unknown.
    """
    ROOT_UNTRUSTED = 16384
    """
    The root certificate is untrusted.
    """
    ROOT_INVALID = 65536
    """
    The root certificate is invalid.
    """
    CHAIN_INCOMPLETE = 131072
    """
    The certificate chain is incomplete.
    """

__all__ = ['CertificateValidity']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
from ..accessibility.x_accessible import XAccessible as XAccessible_1cbc0eb6
from ..accessibility.x_accessible_component import XAccessibleComponent as XAccessibleComponent_b2f21269
from ..accessibility.x_accessible_context import XAccessibleContext as XAccessibleContext_8eae119b

class AccessibleDrawDocumentView(XAccessible_1cbc0eb6, XAccessibleComponent_b2f21269, XAccessibleContext_8eae119b):
    """
    Service Class

    The AccessibleDrawDocumentView service is implemented by views of Draw and Impress documents.
    
    An object that implements the AccessibleDrawDocumentView service provides information about the view of a Draw or Impress document in one of the various view modes. With its children it gives access to the current page and the shapes on that page.
    
    This service gives a simplified view on the underlying document. It tries both to keep the structure of the accessibility representation tree as simple as possible and provide as much relevant information as possible. This has the following consequences:
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleDrawDocumentView <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleDrawDocumentView.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.AccessibleDrawDocumentView'
    __ooo_type_name__: str = 'service'


__all__ = ['AccessibleDrawDocumentView']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt.grid
from __future__ import annotations
import typing
from abc import abstractmethod, ABC

class XSortableGridData(ABC):
    """
    allows to sort the data represented by a XGridDataModel

    See Also:
        `API XSortableGridData <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XSortableGridData.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.grid'
    __ooo_full_ns__: str = 'com.sun.star.awt.grid.XSortableGridData'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.grid.XSortableGridData'

    @abstractmethod
    def getCurrentSortOrder(self) -> typing.Tuple[int, bool]:
        """
        returns the current sort order.
        """
        ...
    @abstractmethod
    def removeColumnSort(self) -> None:
        """
        removes any possibly present sorting of the grid data
        """
        ...
    @abstractmethod
    def sortByColumn(self, ColumnIndex: int, SortAscending: bool) -> None:
        """
        sorts the rows represented by the model by a given column's data.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...

__all__ = ['XSortableGridData']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..util.color import Color as Color_68e908c5


class FilterFieldValue(object):
    """
    Struct Class

    
    **since**
    
        LibreOffice 3.5

    See Also:
        `API FilterFieldValue <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1FilterFieldValue.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.FilterFieldValue'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.FilterFieldValue'
    """Literal Constant ``com.sun.star.sheet.FilterFieldValue``"""

    def __init__(self, IsNumeric: typing.Optional[bool] = False, NumericValue: typing.Optional[float] = 0.0, StringValue: typing.Optional[str] = '', FilterType: typing.Optional[int] = 0, ColorValue: typing.Optional[Color_68e908c5] = Color_68e908c5(0)) -> None:
        """
        Constructor

        Arguments:
            IsNumeric (bool, optional): IsNumeric value.
            NumericValue (float, optional): NumericValue value.
            StringValue (str, optional): StringValue value.
            FilterType (int, optional): FilterType value.
            ColorValue (Color, optional): ColorValue value.
        """
        super().__init__()

        if isinstance(IsNumeric, FilterFieldValue):
            oth: FilterFieldValue = IsNumeric
            self.IsNumeric = oth.IsNumeric
            self.NumericValue = oth.NumericValue
            self.StringValue = oth.StringValue
            self.FilterType = oth.FilterType
            self.ColorValue = oth.ColorValue
            return

        kargs = {
            "IsNumeric": IsNumeric,
            "NumericValue": NumericValue,
            "StringValue": StringValue,
            "FilterType": FilterType,
            "ColorValue": ColorValue,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._is_numeric = kwargs["IsNumeric"]
        self._numeric_value = kwargs["NumericValue"]
        self._string_value = kwargs["StringValue"]
        self._filter_type = kwargs["FilterType"]
        self._color_value = kwargs["ColorValue"]


    @property
    def IsNumeric(self) -> bool:
        """
        selects whether the TableFilterFieldValue.NumericValue or the TableFilterFieldValue.StringValue is used.
        """
        return self._is_numeric

    @IsNumeric.setter
    def IsNumeric(self, value: bool) -> None:
        self._is_numeric = value

    @property
    def NumericValue(self) -> float:
        """
        specifies a numeric value for the condition.
        """
        return self._numeric_value

    @NumericValue.setter
    def NumericValue(self, value: float) -> None:
        self._numeric_value = value

    @property
    def StringValue(self) -> str:
        """
        specifies a string value for the condition.
        """
        return self._string_value

    @StringValue.setter
    def StringValue(self, value: str) -> None:
        self._string_value = value

    @property
    def FilterType(self) -> int:
        """
        Which field should be used for filtering:
        
        **since**
        
            LibreOffice 7.2
        """
        return self._filter_type

    @FilterType.setter
    def FilterType(self, value: int) -> None:
        self._filter_type = value

    @property
    def ColorValue(self) -> Color_68e908c5:
        """
        The color which is used for filtering.
        
        **since**
        
            LibreOffice 7.2
        """
        return self._color_value

    @ColorValue.setter
    def ColorValue(self, value: Color_68e908c5) -> None:
        self._color_value = value


__all__ = ['FilterFieldValue']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.view
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .printable_state import PrintableState as PrintableState_c9fb0c65


class PrintJobEvent(EventObject_a3d70b03):
    """
    Struct Class

    specifies the print progress of an XPrintJob.
    
    com.sun.star.lang.EventObject.Source contains the XPrintJob having changed its state
    
    .
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API PrintJobEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1view_1_1PrintJobEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.view'
    __ooo_full_ns__: str = 'com.sun.star.view.PrintJobEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.view.PrintJobEvent'
    """Literal Constant ``com.sun.star.view.PrintJobEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, State: typing.Optional[PrintableState_c9fb0c65] = PrintableState_c9fb0c65.JOB_STARTED) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            State (PrintableState, optional): State value.
        """

        if isinstance(Source, PrintJobEvent):
            oth: PrintJobEvent = Source
            self.Source = oth.Source
            self.State = oth.State
            return

        kargs = {
            "Source": Source,
            "State": State,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._state = kwargs["State"]
        inst_keys = ('State',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def State(self) -> PrintableState_c9fb0c65:
        """
        contains the current state.
        """
        return self._state

    @State.setter
    def State(self, value: PrintableState_c9fb0c65) -> None:
        self._state = value


__all__ = ['PrintJobEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class FetchResult(object):
    """
    Struct Class

    contains data of several rows of a ContentResultSet.
    
    This struct is returned from XFetchProvider.fetch(), for example.

    See Also:
        `API FetchResult <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1FetchResult.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.FetchResult'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.FetchResult'
    """Literal Constant ``com.sun.star.ucb.FetchResult``"""

    def __init__(self, Rows: typing.Optional[typing.Tuple[object, ...]] = (), StartIndex: typing.Optional[int] = 0, Orientation: typing.Optional[bool] = False, FetchError: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Rows (typing.Tuple[object, ...], optional): Rows value.
            StartIndex (int, optional): StartIndex value.
            Orientation (bool, optional): Orientation value.
            FetchError (int, optional): FetchError value.
        """
        super().__init__()

        if isinstance(Rows, FetchResult):
            oth: FetchResult = Rows
            self.Rows = oth.Rows
            self.StartIndex = oth.StartIndex
            self.Orientation = oth.Orientation
            self.FetchError = oth.FetchError
            return

        kargs = {
            "Rows": Rows,
            "StartIndex": StartIndex,
            "Orientation": Orientation,
            "FetchError": FetchError,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._rows = kwargs["Rows"]
        self._start_index = kwargs["StartIndex"]
        self._orientation = kwargs["Orientation"]
        self._fetch_error = kwargs["FetchError"]


    @property
    def Rows(self) -> typing.Tuple[object, ...]:
        """
        contains the demanded data.
        
        One any contains the data of one whole row. Those methods which use this struct have to specify, what the any has to contain.
        """
        return self._rows

    @Rows.setter
    def Rows(self, value: typing.Tuple[object, ...]) -> None:
        self._rows = value

    @property
    def StartIndex(self) -> int:
        """
        indicates the index of the first row contained in FetchResult.Rows in the original result set.
        
        So if FetchResult.StartIndex equals 3, the first element in the sequence FetchResult.Rows contains the data of the index 3 in the original result set.
        
        The following rows are one after the other, but the direction depends on the value of FetchResult.Direction
        """
        return self._start_index

    @StartIndex.setter
    def StartIndex(self, value: int) -> None:
        self._start_index = value

    @property
    def Orientation(self) -> bool:
        """
        indicates the orientation in which the rows are fetched and set into the sequence FetchResult.Rows.
        
        When FetchResult.Orientation equals TRUE, the rows in FetchResult.Rows are ordered in the same way as in the original result set.
        """
        return self._orientation

    @Orientation.setter
    def Orientation(self, value: bool) -> None:
        self._orientation = value

    @property
    def FetchError(self) -> int:
        """
        indicates whether and which error has occurred, while fetching.
        
        The value may contain zero or more constants of the FetchError constants group.
        """
        return self._fetch_error

    @FetchError.setter
    def FetchError(self, value: int) -> None:
        self._fetch_error = value


__all__ = ['FetchResult']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class TimeIncrement(object):
    """
    Struct Class

    A TimeIncrement describes how tickmarks are positioned on the scale of a date-time axis.
    
    **since**
    
        OOo 3.4

    See Also:
        `API TimeIncrement <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart_1_1TimeIncrement.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.TimeIncrement'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.chart.TimeIncrement'
    """Literal Constant ``com.sun.star.chart.TimeIncrement``"""

    def __init__(self, MajorTimeInterval: typing.Optional[object] = None, MinorTimeInterval: typing.Optional[object] = None, TimeResolution: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            MajorTimeInterval (object, optional): MajorTimeInterval value.
            MinorTimeInterval (object, optional): MinorTimeInterval value.
            TimeResolution (object, optional): TimeResolution value.
        """
        super().__init__()

        if isinstance(MajorTimeInterval, TimeIncrement):
            oth: TimeIncrement = MajorTimeInterval
            self.MajorTimeInterval = oth.MajorTimeInterval
            self.MinorTimeInterval = oth.MinorTimeInterval
            self.TimeResolution = oth.TimeResolution
            return

        kargs = {
            "MajorTimeInterval": MajorTimeInterval,
            "MinorTimeInterval": MinorTimeInterval,
            "TimeResolution": TimeResolution,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._major_time_interval = kwargs["MajorTimeInterval"]
        self._minor_time_interval = kwargs["MinorTimeInterval"]
        self._time_resolution = kwargs["TimeResolution"]


    @property
    def MajorTimeInterval(self) -> object:
        """
        if the any contains a struct of type com.sun.star.chart.TimeInterval this is used as a fixed distance value for the major tickmarks.
        
        Otherwise, if the any is empty or contains an incompatible type, the distance between major tickmarks is calculated automatically by the application.
        """
        return self._major_time_interval

    @MajorTimeInterval.setter
    def MajorTimeInterval(self, value: object) -> None:
        self._major_time_interval = value

    @property
    def MinorTimeInterval(self) -> object:
        """
        if the any contains a struct of type com.sun.star.chart.TimeInterval this is used as a fixed distance value for the minor tickmarks.
        
        Otherwise, if the any is empty or contains an incompatible type, the distance between minor tickmarks is calculated automatically by the application.
        """
        return self._minor_time_interval

    @MinorTimeInterval.setter
    def MinorTimeInterval(self, value: object) -> None:
        self._minor_time_interval = value

    @property
    def TimeResolution(self) -> object:
        """
        if the any contains a constant of type com.sun.star.chart.TimeUnit this is the smallest time unit that is displayed on the date-time axis.
        
        Otherwise, if the any is empty or contains an incompatible type, the resolution is chosen automatically by the application.
        """
        return self._time_resolution

    @TimeResolution.setter
    def TimeResolution(self, value: object) -> None:
        self._time_resolution = value


__all__ = ['TimeIncrement']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.uri
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XVndSunStarScriptUrl(XInterface_8f010a43):
    """
    represents absolute “vnd.sun.star.script” URLs.
    
    These URLs are of the form   vnd-sun-star-script-url = \"VND.SUN.STAR.SCRIPT:\" name [\"?\" parameter *(\"&\" parameter)]   name = 1*schar   parameter = key \"=\" value   key = 1*schar   value = *schar   schar = unreserved / escaped / \"$\" / \"+\" / \",\" / \":\" / \";\" / \"@\" / \"[\" / \"]\"See RFC 3986 RFC 2234 for details.
    
    The names, keys, and values are arbitrary Unicode strings (non-empty Unicode strings in the case of names and keys), encoded as UTF-8 byte sequences. It is an error if any of them does not represent a valid UTF-8 byte sequence. Keys are compared for equality character-by-character, without considering case folding or normalization. There may be multiple parameters with equal keys.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XVndSunStarScriptUrl <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1uri_1_1XVndSunStarScriptUrl.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.uri'
    __ooo_full_ns__: str = 'com.sun.star.uri.XVndSunStarScriptUrl'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.uri.XVndSunStarScriptUrl'

    @abstractmethod
    def getName(self) -> str:
        """
        returns the name part of this URL.
        """
        ...
    @abstractmethod
    def getParameter(self, key: str) -> str:
        """
        returns the value of a parameter with a given key.
        """
        ...
    @abstractmethod
    def hasParameter(self, key: str) -> bool:
        """
        returns whether this URL has a parameter with a given key.
        """
        ...
    @abstractmethod
    def setName(self, name: str) -> None:
        """
        sets the name part of this URL.
        
        **since**
        
            OOo 3.0

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def setParameter(self, key: str, value: str) -> None:
        """
        sets the value of a parameter with a given key.
        
        **since**
        
            OOo 3.0

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XVndSunStarScriptUrl']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.io
from __future__ import annotations
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XOutputStream(XInterface_8f010a43):
    """
    This is the basic interface to write data to a stream.
    
    See the streaming document for further information on chaining and piping streams.

    See Also:
        `API XOutputStream <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XOutputStream.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.XOutputStream'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.io.XOutputStream'

    @abstractmethod
    def closeOutput(self) -> None:
        """
        gets called to indicate that all data has been written.
        
        If this method has not yet been called, no attached XInputStream receives an EOF signal. No further bytes may be written after this method has been called.

        Raises:
            com.sun.star.io.NotConnectedException: ``NotConnectedException``
            com.sun.star.io.BufferSizeExceededException: ``BufferSizeExceededException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def flush(self) -> None:
        """
        flushes out of the stream any data that may exist in buffers.
        
        The semantics of this method are rather vague. See com.sun.star.io.XAsyncOutputMonitor.waitForCompletion() for a similar method with very specific semantics, that is useful in certain scenarios.

        Raises:
            com.sun.star.io.NotConnectedException: ``NotConnectedException``
            com.sun.star.io.BufferSizeExceededException: ``BufferSizeExceededException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def writeBytes(self, aData: uno.ByteSequence) -> None:
        """
        writes the whole sequence to the stream.
        
        (blocking call)

        Raises:
            com.sun.star.io.NotConnectedException: ``NotConnectedException``
            com.sun.star.io.BufferSizeExceededException: ``BufferSizeExceededException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...

__all__ = ['XOutputStream']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n


class TextConversionType(object):
    """
    Const Class

    These constants specify the conversion type to be used with XTextConversion.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API TextConversionType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1TextConversionType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.TextConversionType'
    __ooo_type_name__: str = 'const'

    TO_HANGUL = 1
    """
    Conversion from Hanja to Hangul.
    """
    TO_HANJA = 2
    """
    Conversion from Hangul to Hanja.
    """
    TO_SCHINESE = 3
    """
    Conversion from Traditional to Simplified Chinese.
    """
    TO_TCHINESE = 4
    """
    Conversion from Simplified to Traditional Chinese.
    """

__all__ = ['TextConversionType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.accessibility
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class TextSegment(object):
    """
    Struct Class

    This structure describes a text segment that is embedded in a larger portion of text.
    
    It is used for example by the XAccessibleText interface to describe a text portion that was inserted into or deleted from an accessible text.
    
    The indices TextSegment.SegmentStart and TextSegment.SegmentEnd refer to the enclosing text. The TextSegment.SegmentText member contains the text between these two indices including the start index but not the end index. With it you can use this structure without having to access the XAccessibleText interface that represents the enclosing text.
    
    An empty text segment is expressed by TextSegment.SegmentStart and TextSegment.SegmentEnd set to the same value. While a value of -1 signals an error (like the request for a word after the last character of a text) all other values define the empty string at that position.
    
    The SegmentText member is a copy of the corresponding text segment of the enclosing text. Modifying this structure does not alter the enclosing text.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API TextSegment <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1accessibility_1_1TextSegment.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.accessibility'
    __ooo_full_ns__: str = 'com.sun.star.accessibility.TextSegment'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.accessibility.TextSegment'
    """Literal Constant ``com.sun.star.accessibility.TextSegment``"""

    def __init__(self, SegmentText: typing.Optional[str] = '', SegmentStart: typing.Optional[int] = 0, SegmentEnd: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            SegmentText (str, optional): SegmentText value.
            SegmentStart (int, optional): SegmentStart value.
            SegmentEnd (int, optional): SegmentEnd value.
        """
        super().__init__()

        if isinstance(SegmentText, TextSegment):
            oth: TextSegment = SegmentText
            self.SegmentText = oth.SegmentText
            self.SegmentStart = oth.SegmentStart
            self.SegmentEnd = oth.SegmentEnd
            return

        kargs = {
            "SegmentText": SegmentText,
            "SegmentStart": SegmentStart,
            "SegmentEnd": SegmentEnd,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._segment_text = kwargs["SegmentText"]
        self._segment_start = kwargs["SegmentStart"]
        self._segment_end = kwargs["SegmentEnd"]


    @property
    def SegmentText(self) -> str:
        """
        A copy of the text segment of the enclosing text delimited by the text indices TextSegment.SegmentStart and TextSegment.SegmentEnd.
        
        Modifying it does not alter the enclosing text.
        """
        return self._segment_text

    @SegmentText.setter
    def SegmentText(self, value: str) -> None:
        self._segment_text = value

    @property
    def SegmentStart(self) -> int:
        """
        Index of the first character of the text segment represented by this structure.
        
        The index refers to the enclosing text.
        """
        return self._segment_start

    @SegmentStart.setter
    def SegmentStart(self, value: int) -> None:
        self._segment_start = value

    @property
    def SegmentEnd(self) -> int:
        """
        Index of the character directly behind the last character of the text segment represented by this structure.
        
        The index refers to the enclosing text.
        """
        return self._segment_end

    @SegmentEnd.setter
    def SegmentEnd(self, value: int) -> None:
        self._segment_end = value


__all__ = ['TextSegment']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.accessibility
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.accessibility.AccessibleScrollType import AccessibleScrollTypeProto

class AccessibleScrollType(Enum):
    """
    Enum Class


    See Also:
        `API AccessibleScrollType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1accessibility.html#a8c72ce09bd8167944fb5c7a237420e74>`_
    """
    __ooo_ns__: str = 'com.sun.star.accessibility'
    __ooo_full_ns__: str = 'com.sun.star.accessibility.AccessibleScrollType'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.accessibility.AccessibleScrollType'

    SCROLL_ANYWHERE = cast("AccessibleScrollTypeProto", 'SCROLL_ANYWHERE')
    """
    Scroll the object or string such that as much as possible of the object or string is within the top level window.
    """
    SCROLL_BOTTOM_EDGE = cast("AccessibleScrollTypeProto", 'SCROLL_BOTTOM_EDGE')
    """
    Scroll the bottom edge of the object or string such that the bottom edge is within the top level window.
    """
    SCROLL_BOTTOM_RIGHT = cast("AccessibleScrollTypeProto", 'SCROLL_BOTTOM_RIGHT')
    """
    Scroll the bottom right corner of the object or string such that the bottom right corner is within the top level window.
    """
    SCROLL_LEFT_EDGE = cast("AccessibleScrollTypeProto", 'SCROLL_LEFT_EDGE')
    """
    Scroll the left edge of the object or string such that the left edge is within the top level window.
    """
    SCROLL_RIGHT_EDGE = cast("AccessibleScrollTypeProto", 'SCROLL_RIGHT_EDGE')
    """
    Scroll the right edge of the object or string such that the right edge is within the top level window.
    """
    SCROLL_TOP_EDGE = cast("AccessibleScrollTypeProto", 'SCROLL_TOP_EDGE')
    """
    Scroll the top edge of the object or string such that the top edge is within the top level window.
    """
    SCROLL_TOP_LEFT = cast("AccessibleScrollTypeProto", 'SCROLL_TOP_LEFT')
    """
    Scroll the top left corner of the object or string such that the top left corner is within the top level window.
    """

__all__ = ['AccessibleScrollType']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb


class ContentAction(object):
    """
    Const Class

    specifies actions which can be transported with content events.
    
    The situations under which contents will send ContentEvents of the various action types are described below. The description is broken into a list of useful definitions, a list of events that happen to contents, and a list of reactions taken by contents in response to those events.
    
    The definitions are as follows:
    
    The events that can happen to contents (and that are of interest in this context) are listed next. Note that \"event\" here does not mean an ContentEvent, but rather some event that occurs either because some content processes a command, or because a content gets informed about a relevant change in the underlying system it represents.
    
    Finally, the list of reactions taken by contents in response to the above events gives a description of what kinds of ContentEvents are sent in which situations:

    See Also:
        `API ContentAction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb_1_1ContentAction.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.ContentAction'
    __ooo_type_name__: str = 'const'

    INSERTED = 0
    """
    A content was inserted into a folder content (i.e., while updating the folder).
    
    This action must be notified at the listeners of the folder content.
    """
    REMOVED = 1
    """
    A content was removed from a folder content, but not physically destroyed (i.e., due to rules just applied to the folder).
    
    This action must be notified at the listeners of the folder content.
    """
    DELETED = 2
    """
    A content was physically destroyed.
    
    Events containing this action may be generated at any time. So a content event listener should be prepared to get notified the \"death\" of the related content!
    
    This action must be notified at the listeners of the deleted content.
    """
    EXCHANGED = 4
    """
    This Action indicates that a content has changed its identity (i.e.
    
    after renaming a file system folder).
    
    This action must be notified at the listeners of the exchanged content.
    """
    SEARCH_MATCHED = 128
    """
    This is obsolete and should no longer be used.
    """

__all__ = ['ContentAction']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.presentation
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.presentation.AnimationEffect import AnimationEffectProto

class AnimationEffect(Enum):
    """
    Enum Class


    See Also:
        `API AnimationEffect <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260>`_
    """
    __ooo_ns__: str = 'com.sun.star.presentation'
    __ooo_full_ns__: str = 'com.sun.star.presentation.AnimationEffect'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.presentation.AnimationEffect'

    APPEAR = cast("AnimationEffectProto", 'APPEAR')
    """
    use the animation effect \"Appear\".
    """
    CLOCKWISE = cast("AnimationEffectProto", 'CLOCKWISE')
    """
    use the animation effect \"Clockwise\".
    
    use the fade effect \"Clockwise\".
    """
    CLOSE_HORIZONTAL = cast("AnimationEffectProto", 'CLOSE_HORIZONTAL')
    """
    use the animation effect \"Close Horizontal\".
    
    use the fade effect \"Close Horizontal\".
    """
    CLOSE_VERTICAL = cast("AnimationEffectProto", 'CLOSE_VERTICAL')
    """
    use the animation effect \"Close Vertical\".
    
    use the fade effect \"Close Vertical\".
    """
    COUNTERCLOCKWISE = cast("AnimationEffectProto", 'COUNTERCLOCKWISE')
    """
    use the animation effect \"Counter Clockwise\".
    
    use the fade effect \"Counter Clockwise\".
    """
    DISSOLVE = cast("AnimationEffectProto", 'DISSOLVE')
    """
    use the animation effect \"Spiral Inward Left\".
    
    use the fade effect \"Dissolve\".
    """
    FADE_FROM_BOTTOM = cast("AnimationEffectProto", 'FADE_FROM_BOTTOM')
    """
    use the animation effect \"Fade from Bottom\".
    
    use the fade effect \"Fade from Bottom\".
    """
    FADE_FROM_CENTER = cast("AnimationEffectProto", 'FADE_FROM_CENTER')
    """
    use the animation effect \"Fade from Center\".
    
    use the fade effect \"Fade from Center\".
    """
    FADE_FROM_LEFT = cast("AnimationEffectProto", 'FADE_FROM_LEFT')
    """
    use the animation effect \"Fade from Left\".
    
    use the fade effect \"Fade from Left\".
    """
    FADE_FROM_LOWERLEFT = cast("AnimationEffectProto", 'FADE_FROM_LOWERLEFT')
    """
    use the animation effect \"Fade from Lower Left\".
    
    use the fade effect \"Fade from Lower Left\".
    """
    FADE_FROM_LOWERRIGHT = cast("AnimationEffectProto", 'FADE_FROM_LOWERRIGHT')
    """
    use the animation effect \"Fade from Lower Right\".
    
    use the fade effect \"Fade from Lower Right\".
    """
    FADE_FROM_RIGHT = cast("AnimationEffectProto", 'FADE_FROM_RIGHT')
    """
    use the animation effect \"Fade from Right\".
    
    use the fade effect \"Fade from Right\".
    """
    FADE_FROM_TOP = cast("AnimationEffectProto", 'FADE_FROM_TOP')
    """
    use the animation effect \"Fade from Top\".
    
    use the fade effect \"Fade from Top\".
    """
    FADE_FROM_UPPERLEFT = cast("AnimationEffectProto", 'FADE_FROM_UPPERLEFT')
    """
    use the animation effect \"Fade from Upper Left\".
    
    use the fade effect \"Fade from Upper Left\".
    """
    FADE_FROM_UPPERRIGHT = cast("AnimationEffectProto", 'FADE_FROM_UPPERRIGHT')
    """
    use the animation effect \"Fade from Upper Right\".
    
    use the fade effect \"Fade from Upper Right\".
    """
    FADE_TO_CENTER = cast("AnimationEffectProto", 'FADE_TO_CENTER')
    """
    use the animation effect \"Fade to Center\".
    
    use the fade effect \"Fade to Center\".
    """
    HIDE = cast("AnimationEffectProto", 'HIDE')
    """
    use the animation effect \"Hide\".
    """
    HORIZONTAL_CHECKERBOARD = cast("AnimationEffectProto", 'HORIZONTAL_CHECKERBOARD')
    """
    use the animation effect \"Horizontal Checkerboard\".
    
    use the fade effect \"Horizontal Checkerboard\".
    """
    HORIZONTAL_LINES = cast("AnimationEffectProto", 'HORIZONTAL_LINES')
    """
    use the animation effect \"Horizontal Lines\".
    
    use the fade effect \"Horizontal Lines\".
    """
    HORIZONTAL_ROTATE = cast("AnimationEffectProto", 'HORIZONTAL_ROTATE')
    """
    use the animation effect \"Horizontal Rotate\".
    """
    HORIZONTAL_STRETCH = cast("AnimationEffectProto", 'HORIZONTAL_STRETCH')
    """
    use the animation effect \"Horizontal Stretch\".
    """
    HORIZONTAL_STRIPES = cast("AnimationEffectProto", 'HORIZONTAL_STRIPES')
    """
    use the animation effect \"Horizontal Stripes\".
    
    use the fade effect \"Horizontal Stripes\".
    """
    LASER_FROM_BOTTOM = cast("AnimationEffectProto", 'LASER_FROM_BOTTOM')
    """
    use the animation effect \"Laser from Bottom\".
    """
    LASER_FROM_LEFT = cast("AnimationEffectProto", 'LASER_FROM_LEFT')
    """
    use the animation effect \"Wavy Line from Left\".
    """
    LASER_FROM_LOWERLEFT = cast("AnimationEffectProto", 'LASER_FROM_LOWERLEFT')
    """
    use the animation effect \"Laser from Lower Left\".
    """
    LASER_FROM_LOWERRIGHT = cast("AnimationEffectProto", 'LASER_FROM_LOWERRIGHT')
    """
    use the animation effect \"Laser from Lower Right\".
    """
    LASER_FROM_RIGHT = cast("AnimationEffectProto", 'LASER_FROM_RIGHT')
    """
    use the animation effect \"Laser from Right\".
    """
    LASER_FROM_TOP = cast("AnimationEffectProto", 'LASER_FROM_TOP')
    """
    use the animation effect \"Laser from Top\".
    """
    LASER_FROM_UPPERLEFT = cast("AnimationEffectProto", 'LASER_FROM_UPPERLEFT')
    """
    use the animation effect \"Laser from Upper Left\".
    """
    LASER_FROM_UPPERRIGHT = cast("AnimationEffectProto", 'LASER_FROM_UPPERRIGHT')
    """
    use the animation effect \"Laser from Upper Right\".
    """
    MOVE_FROM_BOTTOM = cast("AnimationEffectProto", 'MOVE_FROM_BOTTOM')
    """
    use the animation effect \"Move from Bottom\".
    
    use the fade effect \"Move from Bottom\".
    """
    MOVE_FROM_LEFT = cast("AnimationEffectProto", 'MOVE_FROM_LEFT')
    """
    use the animation effect \"Move from Left\".
    
    use the fade effect \"Move from Left\".
    """
    MOVE_FROM_LOWERLEFT = cast("AnimationEffectProto", 'MOVE_FROM_LOWERLEFT')
    """
    use the animation effect \"Move from Lower Left\".
    
    use the fade effect \"Move from Lower Left\".
    """
    MOVE_FROM_LOWERRIGHT = cast("AnimationEffectProto", 'MOVE_FROM_LOWERRIGHT')
    """
    use the animation effect \"Move from Lower Right\".
    
    use the fade effect \"Move from Lower Right\".
    """
    MOVE_FROM_RIGHT = cast("AnimationEffectProto", 'MOVE_FROM_RIGHT')
    """
    use the animation effect \"Move from Right\".
    
    use the fade effect \"Move from Right\".
    """
    MOVE_FROM_TOP = cast("AnimationEffectProto", 'MOVE_FROM_TOP')
    """
    use the animation effect \"Move from Top\".
    
    use the fade effect \"Move from Top\".
    """
    MOVE_FROM_UPPERLEFT = cast("AnimationEffectProto", 'MOVE_FROM_UPPERLEFT')
    """
    use the animation effect \"Move from Upper Left\".
    
    use the fade effect \"Move from Upper Left\".
    """
    MOVE_FROM_UPPERRIGHT = cast("AnimationEffectProto", 'MOVE_FROM_UPPERRIGHT')
    """
    use the animation effect \"Move from Upper Right\".
    
    use the fade effect \"Move from Upper Right\".
    """
    MOVE_SHORT_FROM_BOTTOM = cast("AnimationEffectProto", 'MOVE_SHORT_FROM_BOTTOM')
    """
    use the animation effect \"Move Short from Bottom\".
    """
    MOVE_SHORT_FROM_LEFT = cast("AnimationEffectProto", 'MOVE_SHORT_FROM_LEFT')
    """
    use the animation effect \"Move Short from Left\".
    """
    MOVE_SHORT_FROM_LOWERLEFT = cast("AnimationEffectProto", 'MOVE_SHORT_FROM_LOWERLEFT')
    """
    use the animation effect \"Move Short from Lower Left\".
    """
    MOVE_SHORT_FROM_LOWERRIGHT = cast("AnimationEffectProto", 'MOVE_SHORT_FROM_LOWERRIGHT')
    """
    use the animation effect \"Move Short from Lower Right\".
    """
    MOVE_SHORT_FROM_RIGHT = cast("AnimationEffectProto", 'MOVE_SHORT_FROM_RIGHT')
    """
    use the animation effect \"Move Short from Right\".
    """
    MOVE_SHORT_FROM_TOP = cast("AnimationEffectProto", 'MOVE_SHORT_FROM_TOP')
    """
    use the animation effect \"Move Short from Top\".
    """
    MOVE_SHORT_FROM_UPPERLEFT = cast("AnimationEffectProto", 'MOVE_SHORT_FROM_UPPERLEFT')
    """
    use the animation effect \"Move Short from Upper Left\".
    """
    MOVE_SHORT_FROM_UPPERRIGHT = cast("AnimationEffectProto", 'MOVE_SHORT_FROM_UPPERRIGHT')
    """
    use the animation effect \"Move Short from Upper Right\".
    """
    MOVE_SHORT_TO_BOTTOM = cast("AnimationEffectProto", 'MOVE_SHORT_TO_BOTTOM')
    """
    use the animation effect \"Move Short to Bottom\".
    """
    MOVE_SHORT_TO_LEFT = cast("AnimationEffectProto", 'MOVE_SHORT_TO_LEFT')
    """
    use the animation effect \"Move Short to Left\".
    """
    MOVE_SHORT_TO_LOWERLEFT = cast("AnimationEffectProto", 'MOVE_SHORT_TO_LOWERLEFT')
    """
    use the animation effect \"Move Short to Lower Left\".
    """
    MOVE_SHORT_TO_LOWERRIGHT = cast("AnimationEffectProto", 'MOVE_SHORT_TO_LOWERRIGHT')
    """
    use the animation effect \"Move Short to Lower Right\".
    """
    MOVE_SHORT_TO_RIGHT = cast("AnimationEffectProto", 'MOVE_SHORT_TO_RIGHT')
    """
    use the animation effect \"Move Short to Right\".
    """
    MOVE_SHORT_TO_TOP = cast("AnimationEffectProto", 'MOVE_SHORT_TO_TOP')
    """
    use the animation effect \"Move Short to Top\".
    """
    MOVE_SHORT_TO_UPPERLEFT = cast("AnimationEffectProto", 'MOVE_SHORT_TO_UPPERLEFT')
    """
    use the animation effect \"Move Short to Upper Left\".
    """
    MOVE_SHORT_TO_UPPERRIGHT = cast("AnimationEffectProto", 'MOVE_SHORT_TO_UPPERRIGHT')
    """
    use the animation effect \"Move Short to Upper Right\".
    """
    MOVE_TO_BOTTOM = cast("AnimationEffectProto", 'MOVE_TO_BOTTOM')
    """
    use the animation effect \"Move to Bottom\".
    """
    MOVE_TO_LEFT = cast("AnimationEffectProto", 'MOVE_TO_LEFT')
    """
    use the animation effect \"Move to Left\".
    """
    MOVE_TO_LOWERLEFT = cast("AnimationEffectProto", 'MOVE_TO_LOWERLEFT')
    """
    use the animation effect \"Move to Lower Left\".
    """
    MOVE_TO_LOWERRIGHT = cast("AnimationEffectProto", 'MOVE_TO_LOWERRIGHT')
    """
    use the animation effect \"Move to Lower Right\".
    """
    MOVE_TO_RIGHT = cast("AnimationEffectProto", 'MOVE_TO_RIGHT')
    """
    use the animation effect \"Move to Right\".
    """
    MOVE_TO_TOP = cast("AnimationEffectProto", 'MOVE_TO_TOP')
    """
    use the animation effect \"Move to Top\".
    """
    MOVE_TO_UPPERLEFT = cast("AnimationEffectProto", 'MOVE_TO_UPPERLEFT')
    """
    use the animation effect \"Move to Upper Left\".
    """
    MOVE_TO_UPPERRIGHT = cast("AnimationEffectProto", 'MOVE_TO_UPPERRIGHT')
    """
    use the animation effect \"Move to Upper Right\".
    """
    NONE = cast("AnimationEffectProto", 'NONE')
    """
    use no animation effects.
    
    use no fade effects.
    
    No action is performed on click.
    """
    OPEN_HORIZONTAL = cast("AnimationEffectProto", 'OPEN_HORIZONTAL')
    """
    use the animation effect \"Open Horizontal\".
    
    use the fade effect \"Open Horizontal\".
    """
    OPEN_VERTICAL = cast("AnimationEffectProto", 'OPEN_VERTICAL')
    """
    use the animation effect \"Open Vertical\".
    
    use the fade effect \"Open Vertical\".
    """
    PATH = cast("AnimationEffectProto", 'PATH')
    """
    use the animation effect \"Path\".
    """
    RANDOM = cast("AnimationEffectProto", 'RANDOM')
    """
    use the animation effect \"Random\".
    
    use the fade effect \"Random\".
    """
    SPIRALIN_LEFT = cast("AnimationEffectProto", 'SPIRALIN_LEFT')
    """
    use the animation effect \"Spiral Inward Left\".
    
    use the fade effect \"Spiral Inward Left\".
    """
    SPIRALIN_RIGHT = cast("AnimationEffectProto", 'SPIRALIN_RIGHT')
    """
    use the animation effect \"Spiral Inward Right\".
    
    use the fade effect \"Spiral Inward Right\".
    """
    SPIRALOUT_LEFT = cast("AnimationEffectProto", 'SPIRALOUT_LEFT')
    """
    use the animation effect \"Spiral Outward Left\".
    
    use the fade effect \"Spiral Outward Left\".
    """
    SPIRALOUT_RIGHT = cast("AnimationEffectProto", 'SPIRALOUT_RIGHT')
    """
    use the animation effect \"Spiral Outward Right\".
    
    use the fade effect \"Spiral Outward Right\".
    """
    STRETCH_FROM_BOTTOM = cast("AnimationEffectProto", 'STRETCH_FROM_BOTTOM')
    """
    use the animation effect \"Stretch From Bottom\".
    
    use the fade effect \"Stretch from Bottom\".
    """
    STRETCH_FROM_LEFT = cast("AnimationEffectProto", 'STRETCH_FROM_LEFT')
    """
    use the animation effect \"Stretch From Left\".
    
    use the fade effect \"Stretch from Left\".
    """
    STRETCH_FROM_LOWERLEFT = cast("AnimationEffectProto", 'STRETCH_FROM_LOWERLEFT')
    """
    use the animation effect \"Stretch From Lower Left\".
    """
    STRETCH_FROM_LOWERRIGHT = cast("AnimationEffectProto", 'STRETCH_FROM_LOWERRIGHT')
    """
    use the animation effect \"Stretch From Lower Right\".
    """
    STRETCH_FROM_RIGHT = cast("AnimationEffectProto", 'STRETCH_FROM_RIGHT')
    """
    use the animation effect \"Stretch From Right\".
    
    use the fade effect \"Stretch from Right\".
    """
    STRETCH_FROM_TOP = cast("AnimationEffectProto", 'STRETCH_FROM_TOP')
    """
    use the animation effect \"Stretch From Top\".
    
    use the fade effect \"Stretch from Top\".
    """
    STRETCH_FROM_UPPERLEFT = cast("AnimationEffectProto", 'STRETCH_FROM_UPPERLEFT')
    """
    use the animation effect \"Stretch From Upper Left\".
    """
    STRETCH_FROM_UPPERRIGHT = cast("AnimationEffectProto", 'STRETCH_FROM_UPPERRIGHT')
    """
    use the animation effect \"Stretch From Upper Right\".
    """
    VERTICAL_CHECKERBOARD = cast("AnimationEffectProto", 'VERTICAL_CHECKERBOARD')
    """
    use the animation effect \"Vertical Checkerboard\".
    
    use the fade effect \"Vertical Checkerboard\".
    """
    VERTICAL_LINES = cast("AnimationEffectProto", 'VERTICAL_LINES')
    """
    use the animation effect \"Vertical Lines\".
    
    use the fade effect \"Vertical Lines\".
    """
    VERTICAL_ROTATE = cast("AnimationEffectProto", 'VERTICAL_ROTATE')
    """
    use the animation effect \"Vertical Rotate\".
    """
    VERTICAL_STRETCH = cast("AnimationEffectProto", 'VERTICAL_STRETCH')
    """
    use the animation effect \"Vertical Stretch\".
    """
    VERTICAL_STRIPES = cast("AnimationEffectProto", 'VERTICAL_STRIPES')
    """
    use the animation effect \"Vertical Stripes\".
    
    use the fade effect \"Vertical Stripes\".
    """
    WAVYLINE_FROM_BOTTOM = cast("AnimationEffectProto", 'WAVYLINE_FROM_BOTTOM')
    """
    use the animation effect \"Wavy Line from Button\".
    
    use the fade effect \"Wavy Line from Bottom\".
    """
    WAVYLINE_FROM_LEFT = cast("AnimationEffectProto", 'WAVYLINE_FROM_LEFT')
    """
    use the animation effect \"Wavy Line from Left\".
    
    use the fade effect \"Wavy Line from Left\".
    """
    WAVYLINE_FROM_RIGHT = cast("AnimationEffectProto", 'WAVYLINE_FROM_RIGHT')
    """
    use the animation effect \"Wavy Line from Right\".
    
    use the fade effect \"Wavy Line from Right\".
    """
    WAVYLINE_FROM_TOP = cast("AnimationEffectProto", 'WAVYLINE_FROM_TOP')
    """
    use the animation effect \"Wavy Line from Top\".
    
    use the fade effect \"Wavy Line from Top\".
    """
    ZOOM_IN = cast("AnimationEffectProto", 'ZOOM_IN')
    """
    use the animation effect \"Zoom In\".
    """
    ZOOM_IN_FROM_BOTTOM = cast("AnimationEffectProto", 'ZOOM_IN_FROM_BOTTOM')
    """
    use the animation effect \"Zoom In From Bottom\".
    """
    ZOOM_IN_FROM_CENTER = cast("AnimationEffectProto", 'ZOOM_IN_FROM_CENTER')
    """
    use the animation effect \"Zoom In From Center\".
    """
    ZOOM_IN_FROM_LEFT = cast("AnimationEffectProto", 'ZOOM_IN_FROM_LEFT')
    """
    use the animation effect \"Zoom In From Left\".
    """
    ZOOM_IN_FROM_LOWERLEFT = cast("AnimationEffectProto", 'ZOOM_IN_FROM_LOWERLEFT')
    """
    use the animation effect \"Zoom In From Lower Left\".
    """
    ZOOM_IN_FROM_LOWERRIGHT = cast("AnimationEffectProto", 'ZOOM_IN_FROM_LOWERRIGHT')
    """
    use the animation effect \"Zoom In From Lower Right\".
    """
    ZOOM_IN_FROM_RIGHT = cast("AnimationEffectProto", 'ZOOM_IN_FROM_RIGHT')
    """
    use the animation effect \"Zoom In From Right\".
    """
    ZOOM_IN_FROM_TOP = cast("AnimationEffectProto", 'ZOOM_IN_FROM_TOP')
    """
    use the animation effect \"Zoom In From Top\".
    """
    ZOOM_IN_FROM_UPPERLEFT = cast("AnimationEffectProto", 'ZOOM_IN_FROM_UPPERLEFT')
    """
    use the animation effect \"Zoom In From Upper Left\".
    """
    ZOOM_IN_FROM_UPPERRIGHT = cast("AnimationEffectProto", 'ZOOM_IN_FROM_UPPERRIGHT')
    """
    use the animation effect \"Zoom In From Upper Right\".
    """
    ZOOM_IN_SMALL = cast("AnimationEffectProto", 'ZOOM_IN_SMALL')
    """
    use the animation effect \"Zoom In Small\".
    """
    ZOOM_IN_SPIRAL = cast("AnimationEffectProto", 'ZOOM_IN_SPIRAL')
    """
    use the animation effect \"Zoom In Spiral\".
    """
    ZOOM_OUT = cast("AnimationEffectProto", 'ZOOM_OUT')
    """
    use the animation effect \"Zoom Out\".
    """
    ZOOM_OUT_FROM_BOTTOM = cast("AnimationEffectProto", 'ZOOM_OUT_FROM_BOTTOM')
    """
    use the animation effect \"Zoom Out From Bottom\".
    """
    ZOOM_OUT_FROM_CENTER = cast("AnimationEffectProto", 'ZOOM_OUT_FROM_CENTER')
    """
    use the animation effect \"Zoom Out From Center\".
    """
    ZOOM_OUT_FROM_LEFT = cast("AnimationEffectProto", 'ZOOM_OUT_FROM_LEFT')
    """
    use the animation effect \"Zoom Out From Left\".
    """
    ZOOM_OUT_FROM_LOWERLEFT = cast("AnimationEffectProto", 'ZOOM_OUT_FROM_LOWERLEFT')
    """
    use the animation effect \"Zoom Out From Lower Left\".
    """
    ZOOM_OUT_FROM_LOWERRIGHT = cast("AnimationEffectProto", 'ZOOM_OUT_FROM_LOWERRIGHT')
    """
    use the animation effect \"Zoom Out From Lower Right\".
    """
    ZOOM_OUT_FROM_RIGHT = cast("AnimationEffectProto", 'ZOOM_OUT_FROM_RIGHT')
    """
    use the animation effect \"Zoom Out From Right\".
    """
    ZOOM_OUT_FROM_TOP = cast("AnimationEffectProto", 'ZOOM_OUT_FROM_TOP')
    """
    use the animation effect \"Zoom Out From Top\".
    """
    ZOOM_OUT_FROM_UPPERLEFT = cast("AnimationEffectProto", 'ZOOM_OUT_FROM_UPPERLEFT')
    """
    use the animation effect \"Zoom Out From Upper Left\".
    """
    ZOOM_OUT_FROM_UPPERRIGHT = cast("AnimationEffectProto", 'ZOOM_OUT_FROM_UPPERRIGHT')
    """
    use the animation effect \"Zoom Out From Upper Right\".
    """
    ZOOM_OUT_SMALL = cast("AnimationEffectProto", 'ZOOM_OUT_SMALL')
    """
    use the animation effect \"Zoom Out Small\".
    """
    ZOOM_OUT_SPIRAL = cast("AnimationEffectProto", 'ZOOM_OUT_SPIRAL')
    """
    use the animation effect \"Zoom Out Spiral\".
    """

__all__ = ['AnimationEffect']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.binding
from __future__ import annotations
from ..data_aware_control_model import DataAwareControlModel as DataAwareControlModel_27110ef8
from .bindable_control_model import BindableControlModel as BindableControlModel_9a1111a8

class BindableDataAwareControlModel(DataAwareControlModel_27110ef8, BindableControlModel_9a1111a8):
    """
    Service Class

    is a specialization of the com.sun.star.form.DataAwareControlModel which additionally supports binding to external value suppliers.
    
    Control models usually have some kind of value property, which reflects the very current content of the controls associated with this model. For instance, for an com.sun.star.form.component.TextField, this would be the com.sun.star.awt.UnoControlEditModel.Text property of the base service. Similarly, a com.sun.star.form.component.CheckBox has a property com.sun.star.awt.UnoControlCheckBoxModel.State, which reflects the current check state.
    
    Usual com.sun.star.form.DataAwareControlModels can be bound to a column of a com.sun.star.form.component.DataForm, and exchange their content with such a column.In particular, when the com.sun.star.form.component.DataForm is moved to a different record, then the bound control model is updated with the value of it's column in this particular row.On the other hand, when any change in the control model (e.g. resulting from a user entering data in a control associated with the control model) is committed (com.sun.star.form.XBoundComponent.commit()), then the actual data of the control model is written into the associated com.sun.star.form.component.DataForm column.
    
    BindableDataAwareControlModel's additionally support an alternative value binding, which forces them to exchange their value with another foreign instance. In some sense, they are an abstraction of the data aware control models, which only support a specialized, hard-coded value binding (namely the binding to a com.sun.star.form.component.DataForm column).
    
    For this, they provide the XBindableValue interface which allows to set an external component to exchange the value with.
    
    The following rules apply when a data aware control model is bound to an external value binding:
    
    When a BindableDataAwareControlModel is being bound to an external value, using XBindableValue.setValueBinding(), then the control model (its value property, respectively) and the external value are initially synchronized by setting the external value (XValueBinding.getValue()) at the control model.

    See Also:
        `API BindableDataAwareControlModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1binding_1_1BindableDataAwareControlModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.binding'
    __ooo_full_ns__: str = 'com.sun.star.form.binding.BindableDataAwareControlModel'
    __ooo_type_name__: str = 'service'


__all__ = ['BindableDataAwareControlModel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class SortDescriptor(XPropertySet_bc180bfa):
    """
    Service Class

    specifies the properties which can be used to describe a sort order applied to an XSortable.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API SortDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1util_1_1SortDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.SortDescriptor'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CollatorAlgorithm(self) -> str:
        """
        specifies the algorithm for the compare operator (collator).
        
        The collator algorithm may be defined for separate keys in specific implementations. For those this property may not need to be set.
        """
        ...

    @abstractproperty
    def CollatorLocale(self) -> Locale_70d308fa:
        """
        specifies the locale for the compare operator (collator).
        """
        ...

    @abstractproperty
    def IsCaseSensitive(self) -> bool:
        """
        specifies if the case of letters is important when comparing entries.
        """
        ...

    @abstractproperty
    def SortAscending(self) -> bool:
        """
        specifies the sorting order.
        
        The sorting order may be defined for separate keys in specific implementations. For those this property may not need to be set.
        """
        ...

    @abstractproperty
    def SortColumns(self) -> bool:
        """
        specifies if the columns are sorted.
        """
        ...


__all__ = ['SortDescriptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration.backend
from __future__ import annotations
from ...lang.x_initialization import XInitialization as XInitialization_d46c0cca
from ...task.x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51

class InteractionHandler(XInitialization_d46c0cca, XInteractionHandler_bf80e51):
    """
    Service Class

    An interaction request handler that lets the user handle a number of well known requests via GUI dialogs.
    
    The well known requests handled by this service include
    
    The requests marked with an asterisk are only handled if (a) their continuations match certain restrictions (see below), and (b) the necessary resource strings are available (this can be exploited by applications that carry only a subset of all resource files with them).
    
    The continuation restrictions are as follows: Let C be the subset of the provided continuations that are of type com.sun.star.task.XInteractionApprove, com.sun.star.task.XInteractionDisapprove, com.sun.star.task.XInteractionRetry, or com.sun.star.task.XInteractionAbort (or of a derived type). All other continuations are ignored for these requests. The request is only handled if the set C is any of the following:
    
    **since**
    
        OOo 2.0

    See Also:
        `API InteractionHandler <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1InteractionHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration.backend'
    __ooo_full_ns__: str = 'com.sun.star.configuration.backend.InteractionHandler'
    __ooo_type_name__: str = 'service'


__all__ = ['InteractionHandler']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
from ..awt.x_key_handler import XKeyHandler as XKeyHandler_98520a93
from ..awt.x_mouse_click_handler import XMouseClickHandler as XMouseClickHandler_edcb0d59
from ..awt.x_mouse_motion_handler import XMouseMotionHandler as XMouseMotionHandler_fd550de9
from ..frame.x_dispatch import XDispatch as XDispatch_98ff0a9b
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..lang.x_service_info import XServiceInfo as XServiceInfo_af180b5f
from ..view.x_selection_change_listener import XSelectionChangeListener as XSelectionChangeListener_58bf104d

class XSelectionFunction(XKeyHandler_98520a93, XMouseClickHandler_edcb0d59, XMouseMotionHandler_fd550de9, XDispatch_98ff0a9b, XComponent_98dc0ab5, XServiceInfo_af180b5f, XSelectionChangeListener_58bf104d):
    """

    See Also:
        `API XSelectionFunction <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XSelectionFunction.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.XSelectionFunction'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.XSelectionFunction'


__all__ = ['XSelectionFunction']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .rule import Rule as Rule_571307da


class RuleSet(object):
    """
    Struct Class

    describes a set of Rules.
    
    A RuleSet is applied to a folder. It consists of a sequence of rules. Each rule consists of a sequence of RuleTerms describing the objects to which the rule should by applied and the RuleAction which should be performed on the matching objects.

    See Also:
        `API RuleSet <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1RuleSet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.RuleSet'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.RuleSet'
    """Literal Constant ``com.sun.star.ucb.RuleSet``"""

    def __init__(self, Rules: typing.Optional[typing.Tuple[Rule_571307da, ...]] = (), HandleFolder: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            Rules (typing.Tuple[Rule, ...], optional): Rules value.
            HandleFolder (bool, optional): HandleFolder value.
        """
        super().__init__()

        if isinstance(Rules, RuleSet):
            oth: RuleSet = Rules
            self.Rules = oth.Rules
            self.HandleFolder = oth.HandleFolder
            return

        kargs = {
            "Rules": Rules,
            "HandleFolder": HandleFolder,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._rules = kwargs["Rules"]
        self._handle_folder = kwargs["HandleFolder"]


    @property
    def Rules(self) -> typing.Tuple[Rule_571307da, ...]:
        """
        contains a number of rules.
        """
        return self._rules

    @Rules.setter
    def Rules(self, value: typing.Tuple[Rule_571307da, ...]) -> None:
        self._rules = value

    @property
    def HandleFolder(self) -> bool:
        """
        is a flag indicating whether the rules apply to folders, too.
        """
        return self._handle_folder

    @HandleFolder.setter
    def HandleFolder(self, value: bool) -> None:
        self._handle_folder = value


__all__ = ['RuleSet']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .dash_style import DashStyle as DashStyle_b10d0b85


class LineDash(object):
    """
    Struct Class

    A LineDash defines a non-continuous line.

    See Also:
        `API LineDash <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1LineDash.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.LineDash'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.drawing.LineDash'
    """Literal Constant ``com.sun.star.drawing.LineDash``"""

    def __init__(self, Style: typing.Optional[DashStyle_b10d0b85] = DashStyle_b10d0b85.RECT, Dots: typing.Optional[int] = 0, DotLen: typing.Optional[int] = 0, Dashes: typing.Optional[int] = 0, DashLen: typing.Optional[int] = 0, Distance: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Style (DashStyle, optional): Style value.
            Dots (int, optional): Dots value.
            DotLen (int, optional): DotLen value.
            Dashes (int, optional): Dashes value.
            DashLen (int, optional): DashLen value.
            Distance (int, optional): Distance value.
        """
        super().__init__()

        if isinstance(Style, LineDash):
            oth: LineDash = Style
            self.Style = oth.Style
            self.Dots = oth.Dots
            self.DotLen = oth.DotLen
            self.Dashes = oth.Dashes
            self.DashLen = oth.DashLen
            self.Distance = oth.Distance
            return

        kargs = {
            "Style": Style,
            "Dots": Dots,
            "DotLen": DotLen,
            "Dashes": Dashes,
            "DashLen": DashLen,
            "Distance": Distance,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._style = kwargs["Style"]
        self._dots = kwargs["Dots"]
        self._dot_len = kwargs["DotLen"]
        self._dashes = kwargs["Dashes"]
        self._dash_len = kwargs["DashLen"]
        self._distance = kwargs["Distance"]


    @property
    def Style(self) -> DashStyle_b10d0b85:
        """
        This sets the style of this LineDash.
        """
        return self._style

    @Style.setter
    def Style(self, value: DashStyle_b10d0b85) -> None:
        self._style = value

    @property
    def Dots(self) -> int:
        """
        This is the number of dots in this LineDash.
        """
        return self._dots

    @Dots.setter
    def Dots(self, value: int) -> None:
        self._dots = value

    @property
    def DotLen(self) -> int:
        """
        This is the length of a dot.
        """
        return self._dot_len

    @DotLen.setter
    def DotLen(self, value: int) -> None:
        self._dot_len = value

    @property
    def Dashes(self) -> int:
        """
        This is the number of dashes.
        """
        return self._dashes

    @Dashes.setter
    def Dashes(self, value: int) -> None:
        self._dashes = value

    @property
    def DashLen(self) -> int:
        """
        This is the length of a single dash.
        """
        return self._dash_len

    @DashLen.setter
    def DashLen(self, value: int) -> None:
        self._dash_len = value

    @property
    def Distance(self) -> int:
        """
        This is the distance between the dots.
        """
        return self._distance

    @Distance.setter
    def Distance(self, value: int) -> None:
        self._distance = value


__all__ = ['LineDash']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.bridge
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_bridge import XBridge as XBridge_8e4e0a1a
    from .x_instance_provider import XInstanceProvider as XInstanceProvider_b090e4d
    from ..connection.x_connection import XConnection as XConnection_f2320da0

class XBridgeFactory(XInterface_8f010a43):
    """
    factory to create interprocess bridges.

    See Also:
        `API XBridgeFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1bridge_1_1XBridgeFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.bridge'
    __ooo_full_ns__: str = 'com.sun.star.bridge.XBridgeFactory'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.bridge.XBridgeFactory'

    @abstractmethod
    def createBridge(self, sName: str, sProtocol: str, aConnection: XConnection_f2320da0, anInstanceProvider: XInstanceProvider_b090e4d) -> XBridge_8e4e0a1a:
        """
        tries to create a UNO interprocess bridge.
        
        If empty, an anonymous bridge is created, which cannot be retrieved with getBridge(). No BridgeExistsException can be thrown in this case.

        Raises:
            : ````
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getBridge(self, sName: str) -> XBridge_8e4e0a1a:
        """
        tries to get a bridge by this name.
        
        Cannot be retrieved, when the bridge got disposed before.
        """
        ...
    @abstractmethod
    def getExistingBridges(self) -> typing.Tuple[XBridge_8e4e0a1a, ...]:
        """
        returns the sequence of all named and unnamed UNO interprocess bridges that are instantiated at the time the call is made.
        """
        ...

__all__ = ['XBridgeFactory']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame.status
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class LeftRightMarginScale(object):
    """
    Struct Class

    specifies a left and right margin.
    
    **since**
    
        LibreOffice 5.3

    See Also:
        `API LeftRightMarginScale <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1frame_1_1status_1_1LeftRightMarginScale.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame.status'
    __ooo_full_ns__: str = 'com.sun.star.frame.status.LeftRightMarginScale'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.frame.status.LeftRightMarginScale'
    """Literal Constant ``com.sun.star.frame.status.LeftRightMarginScale``"""

    def __init__(self, TextLeft: typing.Optional[int] = 0, Left: typing.Optional[int] = 0, Right: typing.Optional[int] = 0, FirstLine: typing.Optional[int] = 0, ScaleLeft: typing.Optional[int] = 0, ScaleRight: typing.Optional[int] = 0, ScaleFirstLine: typing.Optional[int] = 0, AutoFirstLine: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            TextLeft (int, optional): TextLeft value.
            Left (int, optional): Left value.
            Right (int, optional): Right value.
            FirstLine (int, optional): FirstLine value.
            ScaleLeft (int, optional): ScaleLeft value.
            ScaleRight (int, optional): ScaleRight value.
            ScaleFirstLine (int, optional): ScaleFirstLine value.
            AutoFirstLine (bool, optional): AutoFirstLine value.
        """
        super().__init__()

        if isinstance(TextLeft, LeftRightMarginScale):
            oth: LeftRightMarginScale = TextLeft
            self.TextLeft = oth.TextLeft
            self.Left = oth.Left
            self.Right = oth.Right
            self.FirstLine = oth.FirstLine
            self.ScaleLeft = oth.ScaleLeft
            self.ScaleRight = oth.ScaleRight
            self.ScaleFirstLine = oth.ScaleFirstLine
            self.AutoFirstLine = oth.AutoFirstLine
            return

        kargs = {
            "TextLeft": TextLeft,
            "Left": Left,
            "Right": Right,
            "FirstLine": FirstLine,
            "ScaleLeft": ScaleLeft,
            "ScaleRight": ScaleRight,
            "ScaleFirstLine": ScaleFirstLine,
            "AutoFirstLine": AutoFirstLine,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._text_left = kwargs["TextLeft"]
        self._left = kwargs["Left"]
        self._right = kwargs["Right"]
        self._first_line = kwargs["FirstLine"]
        self._scale_left = kwargs["ScaleLeft"]
        self._scale_right = kwargs["ScaleRight"]
        self._scale_first_line = kwargs["ScaleFirstLine"]
        self._auto_first_line = kwargs["AutoFirstLine"]


    @property
    def TextLeft(self) -> int:
        """
        specifies a left text margin in 1/100th mm.
        """
        return self._text_left

    @TextLeft.setter
    def TextLeft(self, value: int) -> None:
        self._text_left = value

    @property
    def Left(self) -> int:
        """
        specifies a left margin in 1/100th mm.
        """
        return self._left

    @Left.setter
    def Left(self, value: int) -> None:
        self._left = value

    @property
    def Right(self) -> int:
        """
        specifies a right margin in 1/100th mm.
        """
        return self._right

    @Right.setter
    def Right(self, value: int) -> None:
        self._right = value

    @property
    def FirstLine(self) -> int:
        """
        specifies a first line indent relative to TextLeft in 1/100th mm.
        """
        return self._first_line

    @FirstLine.setter
    def FirstLine(self, value: int) -> None:
        self._first_line = value

    @property
    def ScaleLeft(self) -> int:
        """
        specifies a scale value for the left margin in percent.
        """
        return self._scale_left

    @ScaleLeft.setter
    def ScaleLeft(self, value: int) -> None:
        self._scale_left = value

    @property
    def ScaleRight(self) -> int:
        """
        specifies a scale value for the right margin in percent.
        """
        return self._scale_right

    @ScaleRight.setter
    def ScaleRight(self, value: int) -> None:
        self._scale_right = value

    @property
    def ScaleFirstLine(self) -> int:
        """
        specifies a scale value for the first line margin in percent.
        """
        return self._scale_first_line

    @ScaleFirstLine.setter
    def ScaleFirstLine(self, value: int) -> None:
        self._scale_first_line = value

    @property
    def AutoFirstLine(self) -> bool:
        """
        specifies if the automatic calculation of the first line indent occurs.
        """
        return self._auto_first_line

    @AutoFirstLine.setter
    def AutoFirstLine(self, value: bool) -> None:
        self._auto_first_line = value


__all__ = ['LeftRightMarginScale']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.inspection
from __future__ import annotations
from .x_property_handler import XPropertyHandler as XPropertyHandler_3e950fbf

class GenericPropertyHandler(XPropertyHandler_3e950fbf):
    """
    Service Class

    implements a general-purpose XPropertyHandler
    
    The property handler implemented by this service will do an introspection on the provided components, and expose the properties obtained via XIntrospectionAccess.getProperties.
    
    The handler will automatically determine the best type of property control to represent a certain property, depending on the property type. This includes, for example, list box controls to represent enumeration properties.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API GenericPropertyHandler <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1inspection_1_1GenericPropertyHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.inspection'
    __ooo_full_ns__: str = 'com.sun.star.inspection.GenericPropertyHandler'
    __ooo_type_name__: str = 'service'


__all__ = ['GenericPropertyHandler']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .font_slant import FontSlant as FontSlant_849509ed


class FontDescriptor(object):
    """
    Struct Class

    describes the characteristics of a font.
    
    For example, this can be used to select a font.

    See Also:
        `API FontDescriptor <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1FontDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.FontDescriptor'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.awt.FontDescriptor'
    """Literal Constant ``com.sun.star.awt.FontDescriptor``"""

    def __init__(self, Name: typing.Optional[str] = '', Height: typing.Optional[int] = 0, Width: typing.Optional[int] = 0, StyleName: typing.Optional[str] = '', Family: typing.Optional[int] = 0, CharSet: typing.Optional[int] = 0, Pitch: typing.Optional[int] = 0, CharacterWidth: typing.Optional[float] = 0.0, Weight: typing.Optional[float] = 0.0, Slant: typing.Optional[FontSlant_849509ed] = FontSlant_849509ed.NONE, Underline: typing.Optional[int] = 0, Strikeout: typing.Optional[int] = 0, Orientation: typing.Optional[float] = 0.0, Kerning: typing.Optional[bool] = False, WordLineMode: typing.Optional[bool] = False, Type: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            Height (int, optional): Height value.
            Width (int, optional): Width value.
            StyleName (str, optional): StyleName value.
            Family (int, optional): Family value.
            CharSet (int, optional): CharSet value.
            Pitch (int, optional): Pitch value.
            CharacterWidth (float, optional): CharacterWidth value.
            Weight (float, optional): Weight value.
            Slant (FontSlant, optional): Slant value.
            Underline (int, optional): Underline value.
            Strikeout (int, optional): Strikeout value.
            Orientation (float, optional): Orientation value.
            Kerning (bool, optional): Kerning value.
            WordLineMode (bool, optional): WordLineMode value.
            Type (int, optional): Type value.
        """
        super().__init__()

        if isinstance(Name, FontDescriptor):
            oth: FontDescriptor = Name
            self.Name = oth.Name
            self.Height = oth.Height
            self.Width = oth.Width
            self.StyleName = oth.StyleName
            self.Family = oth.Family
            self.CharSet = oth.CharSet
            self.Pitch = oth.Pitch
            self.CharacterWidth = oth.CharacterWidth
            self.Weight = oth.Weight
            self.Slant = oth.Slant
            self.Underline = oth.Underline
            self.Strikeout = oth.Strikeout
            self.Orientation = oth.Orientation
            self.Kerning = oth.Kerning
            self.WordLineMode = oth.WordLineMode
            self.Type = oth.Type
            return

        kargs = {
            "Name": Name,
            "Height": Height,
            "Width": Width,
            "StyleName": StyleName,
            "Family": Family,
            "CharSet": CharSet,
            "Pitch": Pitch,
            "CharacterWidth": CharacterWidth,
            "Weight": Weight,
            "Slant": Slant,
            "Underline": Underline,
            "Strikeout": Strikeout,
            "Orientation": Orientation,
            "Kerning": Kerning,
            "WordLineMode": WordLineMode,
            "Type": Type,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._name = kwargs["Name"]
        self._height = kwargs["Height"]
        self._width = kwargs["Width"]
        self._style_name = kwargs["StyleName"]
        self._family = kwargs["Family"]
        self._char_set = kwargs["CharSet"]
        self._pitch = kwargs["Pitch"]
        self._character_width = kwargs["CharacterWidth"]
        self._weight = kwargs["Weight"]
        self._slant = kwargs["Slant"]
        self._underline = kwargs["Underline"]
        self._strikeout = kwargs["Strikeout"]
        self._orientation = kwargs["Orientation"]
        self._kerning = kwargs["Kerning"]
        self._word_line_mode = kwargs["WordLineMode"]
        self._type = kwargs["Type"]


    @property
    def Name(self) -> str:
        """
        specifies the exact name of the font.
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value

    @property
    def Height(self) -> int:
        """
        specifies the height of the font in the measure of the destination.
        """
        return self._height

    @Height.setter
    def Height(self, value: int) -> None:
        self._height = value

    @property
    def Width(self) -> int:
        """
        specifies the width of the font in the measure of the destination.
        """
        return self._width

    @Width.setter
    def Width(self, value: int) -> None:
        self._width = value

    @property
    def StyleName(self) -> str:
        """
        specifies the style name of the font.
        """
        return self._style_name

    @StyleName.setter
    def StyleName(self, value: str) -> None:
        self._style_name = value

    @property
    def Family(self) -> int:
        """
        specifies the general style of the font.
        
        Use one value out of the constant group com.sun.star.awt.FontFamily.
        """
        return self._family

    @Family.setter
    def Family(self, value: int) -> None:
        self._family = value

    @property
    def CharSet(self) -> int:
        """
        specifies the character set which is supported by the font.
        
        Use one value out of the constant group com.sun.star.awt.CharSet.
        """
        return self._char_set

    @CharSet.setter
    def CharSet(self, value: int) -> None:
        self._char_set = value

    @property
    def Pitch(self) -> int:
        """
        specifies the pitch of the font.
        
        Use one value out of the constant group com.sun.star.awt.FontPitch.
        """
        return self._pitch

    @Pitch.setter
    def Pitch(self, value: int) -> None:
        self._pitch = value

    @property
    def CharacterWidth(self) -> float:
        """
        specifies the character width.
        
        Depending on the specified width, a font that supports this width may be selected.
        
        The value is expressed as a percentage.
        """
        return self._character_width

    @CharacterWidth.setter
    def CharacterWidth(self, value: float) -> None:
        self._character_width = value

    @property
    def Weight(self) -> float:
        """
        specifies the thickness of the line.
        
        Depending on the specified weight, a font that supports this thickness may be selected.
        
        The value is expressed as a percentage.
        """
        return self._weight

    @Weight.setter
    def Weight(self, value: float) -> None:
        self._weight = value

    @property
    def Slant(self) -> FontSlant_849509ed:
        """
        specifies the slant of the font.
        """
        return self._slant

    @Slant.setter
    def Slant(self, value: FontSlant_849509ed) -> None:
        self._slant = value

    @property
    def Underline(self) -> int:
        """
        specifies the kind of underlining.
        
        Use one value out of the constant group com.sun.star.awt.FontUnderline.
        """
        return self._underline

    @Underline.setter
    def Underline(self, value: int) -> None:
        self._underline = value

    @property
    def Strikeout(self) -> int:
        """
        specifies the kind of strikeout.
        
        Use one value out of the constant group com.sun.star.awt.FontStrikeout.
        """
        return self._strikeout

    @Strikeout.setter
    def Strikeout(self, value: int) -> None:
        self._strikeout = value

    @property
    def Orientation(self) -> float:
        """
        specifies the rotation of the font.
        
        The unit of measure is degrees; 0 is the baseline.
        """
        return self._orientation

    @Orientation.setter
    def Orientation(self, value: float) -> None:
        self._orientation = value

    @property
    def Kerning(self) -> bool:
        """
        For requesting, it specifies if there is a kerning table available.
        
        For selecting, it specifies if the kerning table is to be used.
        """
        return self._kerning

    @Kerning.setter
    def Kerning(self, value: bool) -> None:
        self._kerning = value

    @property
    def WordLineMode(self) -> bool:
        """
        specifies if only words get underlined.
        
        TRUE means that only non-space characters get underlined, FALSE means that the spacing also gets underlined.
        
        This property is only valid if the property com.sun.star.awt.FontDescriptor.Underline is not FontUnderline.NONE.
        """
        return self._word_line_mode

    @WordLineMode.setter
    def WordLineMode(self, value: bool) -> None:
        self._word_line_mode = value

    @property
    def Type(self) -> int:
        """
        specifies the technology of the font representation.
        
        One or more values out of the constant group com.sun.star.awt.FontType can be combined by an arithmetical or-operation.
        """
        return self._type

    @Type.setter
    def Type(self, value: int) -> None:
        self._type = value


__all__ = ['FontDescriptor']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
from ..beans.x_properties_change_notifier import XPropertiesChangeNotifier as XPropertiesChangeNotifier_7a7b111c
from ..beans.x_property_container import XPropertyContainer as XPropertyContainer_c600e71
from ..beans.x_property_set_info_change_notifier import XPropertySetInfoChangeNotifier as XPropertySetInfoChangeNotifier_d524130c
from ..container.x_child import XChild as XChild_a6390b07
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from .x_command_info_change_notifier import XCommandInfoChangeNotifier as XCommandInfoChangeNotifier_6358106b
from .x_command_processor import XCommandProcessor as XCommandProcessor_dfe80d19
from .x_command_processor2 import XCommandProcessor2 as XCommandProcessor2_ed330d4b
from .x_content import XContent as XContent_79db0975

class WebDAVDocumentContent(XPropertiesChangeNotifier_7a7b111c, XPropertyContainer_c600e71, XPropertySetInfoChangeNotifier_d524130c, XChild_a6390b07, XComponent_98dc0ab5, XCommandInfoChangeNotifier_6358106b, XCommandProcessor2_ed330d4b, XCommandProcessor_dfe80d19, XContent_79db0975):
    """
    Service Class

    A DCP Document is a container for Document data/content.
    
    The data/content may be anything, a WebDAV server, like an HTTP server, does not necessarily mandate what type of data/content may be contained within Documents. The type of data/content is defined by the MediaType property which is different from the content type returned from the XContent.getContentType() method. The MediaType property is mapped to the equivalent WebDAV property and the WebDAV server calculates the value.

    See Also:
        `API WebDAVDocumentContent <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ucb_1_1WebDAVDocumentContent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.WebDAVDocumentContent'
    __ooo_type_name__: str = 'service'


__all__ = ['WebDAVDocumentContent']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .item_list_event import ItemListEvent as ItemListEvent_afba0b81
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XItemListListener(XEventListener_c7230c4a):
    """
    describes a listener for changes in an item list

    See Also:
        `API XItemListListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XItemListListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XItemListListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XItemListListener'

    @abstractmethod
    def allItemsRemoved(self, Event: EventObject_a3d70b03) -> None:
        """
        is called when the list has been completely cleared, i.e.
        
        after an invocation of XItemList.removeAllItems()
        """
        ...
    @abstractmethod
    def itemListChanged(self, Event: EventObject_a3d70b03) -> None:
        """
        is called when the changes to the item list which occurred are too complex to be notified in single events.
        
        Consumers of this event should discard their cached information about the current item list, and completely refresh it from the XItemList's current state.
        """
        ...
    @abstractmethod
    def listItemInserted(self, Event: ItemListEvent_afba0b81) -> None:
        """
        is called when an item is inserted into the list
        """
        ...
    @abstractmethod
    def listItemModified(self, Event: ItemListEvent_afba0b81) -> None:
        """
        is called when an item in the list is modified, i.e.
        
        its text or image changed
        """
        ...
    @abstractmethod
    def listItemRemoved(self, Event: ItemListEvent_afba0b81) -> None:
        """
        is called when an item is removed from the list
        """
        ...

__all__ = ['XItemListListener']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.datatransfer
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_mime_content_type import XMimeContentType as XMimeContentType_5c141064

class XMimeContentTypeFactory(XInterface_8f010a43):
    """
    Implementations of this interface do create a com.sun.star.datatransfer.XMimeContentType from a given string that represents a MIME content-type (see Rfc2045 and Rfc2046).

    See Also:
        `API XMimeContentTypeFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1datatransfer_1_1XMimeContentTypeFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.XMimeContentTypeFactory'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.datatransfer.XMimeContentTypeFactory'

    @abstractmethod
    def createMimeContentType(self, aContentType: str) -> XMimeContentType_5c141064:
        """
        Creates an object that implements XMimeContentType.
        
        Exception: Quoted parameter values may contain spaces.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XMimeContentTypeFactory']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
from abc import abstractmethod
from .x_text_cursor import XTextCursor as XTextCursor_a60c0b48

class XWordCursor(XTextCursor_a60c0b48):
    """
    makes it possible to move a cursor word by word.

    See Also:
        `API XWordCursor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XWordCursor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.XWordCursor'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.text.XWordCursor'

    @abstractmethod
    def gotoEndOfWord(self, bExpand: bool) -> bool:
        """
        moves the cursor to the end of the current word.
        """
        ...
    @abstractmethod
    def gotoNextWord(self, bExpand: bool) -> bool:
        """
        moves the cursor to the next word.
        
        Note: the function returning TRUE does not necessarily mean that the cursor is located at the next word, or any word at all! This may happen for example if it travels over empty paragraphs.
        """
        ...
    @abstractmethod
    def gotoPreviousWord(self, bExpand: bool) -> bool:
        """
        moves the cursor to the previous word.
        
        Note: the function returning TRUE does not necessarily mean that the cursor is located at the previous word, or any word at all! This may happen for example if it travels over empty paragraphs.
        """
        ...
    @abstractmethod
    def gotoStartOfWord(self, bExpand: bool) -> bool:
        """
        moves the cursor to the start of the current word.
        """
        ...
    @abstractmethod
    def isEndOfWord(self) -> bool:
        """
        determines if the cursor is positioned at the end of a word.
        """
        ...
    @abstractmethod
    def isStartOfWord(self) -> bool:
        """
        determines if the cursor is positioned at the start of a word.
        """
        ...

__all__ = ['XWordCursor']

